@@ -2,6 +2,7 @@
 import argparse
 
 from notebuild.shell import run_shell, run_shell_list
+from notejob.run.core import start
 from notetool.tool.log import log
 
 logger = log("notebuild")
@@ -12,10 +13,11 @@ class JobScheduler:
         pass
 
     def start(self):
-        print("start")
+        logger.info("start")
+        start()
 
     def stop(self):
-        print("stop")
+        logger.info("stop")
 
     def restart(self):
         self.stop()
